@@ -5,7 +5,8 @@ from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
 from djangoldp_circle.models import Circle, CircleMember, manage_deleted_owner
-from djangoldp_circle.tests.models import User
+from djangoldp_circle.tests.utils import get_random_user
+from djangoldp_account.models import LDPUser
 
 
 class SaveTestCase(APITestCase):
@@ -13,9 +14,7 @@ class SaveTestCase(APITestCase):
         self.client = APIClient()
 
     def setUpLoggedInUser(self):
-        self.user = User(email='test@mactest.co.uk', first_name='Test', last_name='Mactest', username='test',
-                         password='glass onion')
-        self.user.save()
+        self.user = get_random_user()
         self.client.force_authenticate(user=self.user)
 
     def setUpCircle(self, status_choice='Public', owner=None):
@@ -24,18 +23,14 @@ class SaveTestCase(APITestCase):
 
         self.circle = Circle.objects.create(name='Test', status=status_choice, owner=owner)
 
-    def _get_random_user(self):
-        return User.objects.create(email='{}@test.co.uk'.format(str(uuid.uuid4())), first_name='Test', last_name='Test',
-                                   username=str(uuid.uuid4()))
-
     # tests for handling owner removed functionality
     def test_owner_removed_listener_second_admin(self):
         # there is a circle with 2 admins and 3 total users
         self.setUpLoggedInUser()
         self.setUpCircle()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=False)
-        admin_user = self._get_random_user()
+        admin_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=admin_user, is_admin=True)
 
         # the owner user was deleted - but there is another admin in the circle
@@ -52,7 +47,7 @@ class SaveTestCase(APITestCase):
         # the owner user was deleted - there is no other admin but there is another user
         self.setUpLoggedInUser()
         self.setUpCircle()
-        another_user = self._get_random_user()
+        another_user = get_random_user()
         CircleMember.objects.create(circle=self.circle, user=another_user, is_admin=False)
 
         cm = self.circle.members.get(user=self.user)
@@ -77,4 +72,4 @@ class SaveTestCase(APITestCase):
         self.setUpCircle()
         self.circle.delete()
         self.assertEqual(Circle.objects.count(), 0)
-        self.assertEqual(User.objects.count(), 1)
+        self.assertEqual(LDPUser.objects.count(), 1)
