@@ -76,6 +76,20 @@ class CirclesJoinableViewset(LDPViewSet):
         return super().get_queryset().exclude(members__user=self.request.user.id)\
             .filter(status="Public")
 
+class CircleAccessRequestFilteredByUserViewSet(LDPViewSet):
+    '''Viewset for accessing all AccessRequests linked to me'''
+
+    filter_backends = [LocalObjectFilterBackend]
+
+    def __init__(self, **kwargs):
+        from djangoldp_circle.models import CircleAccessRequest
+
+        kwargs['model'] = CircleAccessRequest
+        kwargs['nested_fields'] = CircleAccessRequest.nested.fields()
+        super().__init__(**kwargs)
+
+    def get_queryset(self):
+        return super().get_queryset().filter(user=self.request.user.id)
 
 class CircleAccessRequestServerNotificationView(APIView):
     '''
